jQuery( function( $ ) {
    /**
     * Load videos in sections
     */
    var loadSectionVideos = function() {

        /**
         * Get youtube video id from url
         *
         * @param url Url of the youtube video
         *
         * @return The video id
         */
        function youtubeGetVideoIdFromUrl( url ) {
            var regExp = /^.*((youtu.be\/)|(v\/)|(\/u\/\w\/)|(embed\/)|(watch\?))\??v?=?([^#\&\?]*).*/;
            var match = url.match( regExp );
            return ( match && match[ 7 ].length == 11 ) ? match[ 7 ] : false;
        }

        /**
         * Init video player on section videos
         */
        var $sectionVideo = $( '.section__thumbnail-video' );
        $sectionVideo.click( function( e ) {
            var videoUrl = $( this ).attr( 'href' );
            var videoId = youtubeGetVideoIdFromUrl( videoUrl );
            var videoContainer = $( this ).find( '.section__video' ).get( 0 );

            if ( !videoId || !videoContainer )
                return;

            e.preventDefault();

            $( this ).find( 'i' ).hide();

            new YT.Player(
                videoContainer,
                {
                    height: '100%',
                    width: '100%',
                    videoId: videoId,
                    playerVars: {
                        autoplay: 1,
                        modestbranding: 1,
                        rel: 0,
                    },
                },
            );
        } );

        /**
         * Init background videos in sections
         */
        var $backgroundVideoSections = $( '[data-property]' );

        $backgroundVideoSections.each( function() {
            var $section = $( this );
            var videoProperty = $section.data( 'property' );

            if ( videoProperty ) {
                var youtubeRegExp = new RegExp( /^((?:https?:)?\/\/)?((?:www|m)\.)?((?:youtube\.com|youtu.be))(\/(?:[\w\-]+\?v=|embed\/|v\/)?)([\w\-]+)(\S+)?$/ );
                var vimeoRegExp = new RegExp( /(?:https?\:\/\/)?(?:www\.)?(?:vimeo\.com\/)([0-9]+)/ );

                var $videoInit = $( '<div></div>' );

                videoProperty.onReady = function() {
                    $videoInit.remove();
                };

                $videoInit.data( 'property', videoProperty );
                $videoInit.appendTo( $section );

                if ( youtubeRegExp.test( videoProperty.videoURL ) ) {
                    $videoInit.YTPlayer();
                }
                else if ( vimeoRegExp.test( videoProperty.videoURL ) ) {
                    $videoInit.vimeo_player();
                }
            }
        } );
    }

    /**
     * Load section videos when the Youtube API is ready
     */
    if ( !window.YT.Player ) {
        if ( window.onYouTubeIframeAPIReady &&
            typeof window.onYouTubeIframeAPIReady === 'function' ) {
            var YTAPIReady = window.onYouTubeIframeAPIReady;

            window.onYouTubeIframeAPIReady = function() {
                loadSectionVideos();
                YTAPIReady();
            };
        }
        else {
            window.onYouTubeIframeAPIReady = loadSectionVideos;
        }
    }
    else {
        loadSectionVideos();
    }

    /**
     * Load section videos in the block editor when a block is re-rendered
     */
    var isBlockEditor = $( 'body' ).hasClass( 'block-editor-page' );

    if ( isBlockEditor ) {
        // Create a mutation observer to detect blocks re-render
        var blocksObserver = new MutationObserver( function( mutationList, observer ) {

            var $renderedBlocks = $([]);

            // Loop over each mutation to find if some blocks have re-rendered
            mutationList.forEach( function( mutation ) {
                // We only care about grimlock section blocks mutations
                if ( mutation.type === 'childList' && $( mutation.target ).parent().hasClass( 'wp-block' ) && $( mutation.target ).find( '.grimlock-section' ).length )
                    $renderedBlocks = $renderedBlocks.add( $( mutation.target ) );
            } );

            // Init animations for all blocks that re-rendered
            $renderedBlocks.each( function() {
                loadSectionVideos();
            } );
        } );

        blocksObserver.observe( $( '.block-editor' ).get( 0 ), { subtree: true, childList: true } );
    }
} );