<?php
/**
 * Grimlock_Video_Section_Component Class
 *
 * @author  Themosaurus
 * @since   1.0.0
 * @package  grimlock-video
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The class to generate section in page.
 */
class Grimlock_Video_Section_Component extends Grimlock_Section_Component {
	/**
	 * Setup class.
	 *
	 * @param array $props
	 * @since 1.0.0
	 */
	public function __construct( $props = array() ) {
		parent::__construct( wp_parse_args( $props, array(
			'video_url' => '',
		) ) );
	}

	/**
	 * Display the section featured image using `thumbnail` prop.
	 *
	 * @since 1.0.0
	 */
	protected function render_thumbnail() {
		if ( ! empty( $this->props['thumbnail'] ) ) :
			$attachment_id = attachment_url_to_postid( $this->props['thumbnail'] ); ?>
            <div class="grimlock-section__thumbnail section__thumbnail">

	            <?php if ( ! empty( $this->props['video_url'] ) ) : ?>
		            <a href="<?php echo esc_url( $this->props['video_url'] ) ?>" target="_blank" class="section__thumbnail-video" style="font-size: 1.5rem; color: #fff; display: flex; justify-content: center; align-items: center; position: absolute; top: 0; bottom: 0; left: 0; right: 0">
			            <i class="fa fa-play-circle fa-5x"></i>
			            <div class="section__video"></div>
		            </a>
	            <?php endif; ?>

	            <?php if ( ! empty( $attachment_id ) ) :
		            echo wp_get_attachment_image( $attachment_id, false, false, array( 'src' => esc_url( $this->props['thumbnail'] ), 'class' => 'grimlock-section__thumbnail-img section__thumbnail-img img-fluid' ) );
	            else : ?>
		            <img class="grimlock-section__thumbnail-img section__thumbnail-img img-fluid" src="<?php echo esc_url( $this->props['thumbnail'] ); ?>" alt="<?php echo esc_attr( $this->props['thumbnail_alt'] ); ?>" />
	            <?php endif; ?>
	            <div class="grimlock-section__thumbnail-caption section__thumbnail-caption"><?php echo $this->props['thumbnail_caption']; ?></div>
            </div><!-- .section__thumbnail -->
			<?php
		endif;
	}

	/**
	 * Display the current component with props data on page.
	 *
	 * @since 1.0.0
	 */
	public function render() {
		if ( $this->is_displayed() ) : ?>
            <<?php $this->render_el(); ?> <?php $this->render_id(); ?> <?php $this->render_class(); ?> <?php $this->render_style(); ?> <?php $this->render_role(); ?> <?php $this->render_data_attributes(); ?>>
            <div class="region__inner" <?php $this->render_inner_style(); ?>>
                <div class="region__container">
                    <div class="region__row">
                        <div class="region__col region__col--1">
							<?php $this->render_thumbnail(); ?>
                        </div><!-- .region__col -->
                        <div class="region__col region__col--2">
							<?php
							$this->render_header();
							$this->render_content();
							$this->render_footer(); ?>
                        </div><!-- .region__col -->
                    </div><!-- .region__row -->
                </div><!-- .region__container -->
            </div><!-- .region__inner -->
            </<?php $this->render_el(); ?>><!-- .grimlock-section -->
		<?php endif;
	}
}
