<?php
/**
 * Grimlock_Video_Hero_Customizer Class
 *
 * @author  Themosaurus
 * @since   1.0.0
 * @package grimlock-video
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock Customizer class for the Grimlock Video add-on.
 */
class Grimlock_Video_Hero_Customizer extends Grimlock_Base_Customizer {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$this->id      = 'hero';
		$this->section = 'grimlock_hero_customizer_section';

		add_filter( 'grimlock_hero_args',                   array( $this, 'add_args'                        ), 10, 1 );
		add_action( 'after_setup_theme',                    array( $this, 'add_customizer_fields'           ), 20    );
		add_filter( 'grimlock_customizer_controls_js_data', array( $this, 'add_customizer_controls_js_data' ), 10, 1 );
	}

	/**
	 * @param $args
	 *
	 * @return mixed
	 */
	public function add_args( $args ) {
		$video_property = array(
			'videoURL'           => esc_url( $this->get_theme_mod( 'hero_video_url' ) ),
			'containment'        => '#hero',
			'ratio'              => 'auto',
			'optimizeDisplay'    => true,
			'autoPlay'           => true,
			'mute'               => intval( $this->get_theme_mod( 'hero_video_volume' ) ) <= 0,
			'vol'                => intval( $this->get_theme_mod( 'hero_video_volume' ) ),
			'startAt'            => 0,
			'opacity'            => 1,
			'gaTrack'            => false,
			'showControls'       => false,
			'showYTLogo'         => false,
			'loop'               => (bool)$this->get_theme_mod( 'hero_video_loop' ),
			'remember_last_time' => false,
			'stopMovieOnBlur'    => false,
		);

		if ( ! wp_is_mobile() ) {
			$args['data_attributes']['property'] = esc_attr( json_encode( $video_property ) );
		}

		return $args;
	}

	/**
	 * @param $js_data
	 *
	 * @return mixed
	 */
	public function add_customizer_controls_js_data( $js_data ) {
		$js_data['tabs'][$this->section][2]['controls'][] = 'hero_video_url';
		$js_data['tabs'][$this->section][2]['controls'][] = 'hero_video_volume';
		$js_data['tabs'][$this->section][2]['controls'][] = 'hero_video_loop';
		return $js_data;
	}

	/**
	 * Add settings and custom controls for the Theme Customizer.
	 *
	 * @since 1.0.0
	 */
	public function add_customizer_fields() {
		$this->defaults = apply_filters( 'grimlock_video_hero_customizer_defaults', array(
			'hero_video_url'    => '',
			'hero_video_volume' => 0,
			'hero_video_loop'   => true,
		) );

		$this->add_url_field(    array( 'priority' => 301 ) );
		$this->add_volume_field( array( 'priority' => 302 ) );
		$this->add_loop_field(   array( 'priority' => 303 ) );
	}

	/**
	 * @param array $args
	 */
	public function add_url_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'      => 'text',
				'section'   => $this->section,
				'label'     => esc_attr__( 'Background Video URL', 'grimlock_video' ),
				'settings'  => 'hero_video_url',
				'default'   => $this->get_default( 'hero_video_url' ),
				'priority'  => 10,
				'transport' => 'refresh',
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_video_hero_customizer_url_field_args', $args ) );
		}
	}

	/**
	 * @param array $args
	 */
	public function add_volume_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'      => 'slider',
				'section'   => $this->section,
				'label'     => esc_attr__( 'Background Video Volume', 'grimlock_video' ),
				'settings'  => 'hero_video_volume',
				'default'   => $this->get_default( 'hero_video_volume' ),
				'priority'  => 10,
				'choices'   => array(
					'min'   => 0,
					'max'   => 100,
					'step'  => 1,
				),
				'transport' => 'refresh',
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_video_hero_customizer_volume_field_args', $args ) );
		}
	}

	/**
	 * @param array $args
	 */
	public function add_loop_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'      => 'checkbox',
				'section'   => $this->section,
				'label'     => esc_attr__( 'Loop Background Video', 'grimlock_video' ),
				'settings'  => 'hero_video_loop',
				'default'   => $this->get_default( 'hero_video_loop' ),
				'priority'  => 10,
				'transport' => 'refresh',
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_video_hero_customizer_loop_field_args', $args ) );
		}
	}
}

return new Grimlock_Video_Hero_Customizer();
